@@ -15,11 +15,13 @@ class Template(string.Template):
 
 
 @public
-class attrdict(dict):
+# Implicit generic "Any". Use "typing.Dict" and specify generic parameters
+# [type-arg]
+class attrdict(dict):                               # type: ignore
     """Follow attribute paths."""
-    def __getitem__(self, key):
+    def __getitem__(self, key: str) -> str:
         parts = key.split('.')
-        value = super().__getitem__(parts.pop(0))
+        value: str = super().__getitem__(parts.pop(0))
         while parts:
             value = getattr(value, parts.pop(0), _missing)
             if value is _missing:
